@@ -89,7 +89,12 @@ export const jsFeatures = {
 
 export type CSSFeature = keyof typeof cssFeatures
 export const cssFeatures = {
+  ColorFunctions: true,
+  GradientDoublePosition: true,
+  GradientInterpolation: true,
+  GradientMidpoints: true,
   HexRGBA: true,
+  HWB: true,
   InlineStyle: true,
   InsetProperty: true,
   IsPseudoClass: true,
@@ -465,20 +470,36 @@ import('./kangax').then(kangax => {
     // From https://bugzilla.mozilla.org/show_bug.cgi?id=1670044
     js.ArbitraryModuleNamespaceNames.Firefox = { 87: { force: true } }
 
-    // This feature has been implemented in Safari but I have no idea what version
-    // this bug corresponds to: https://bugs.webkit.org/show_bug.cgi?id=217576
+    // From https://developer.apple.com/documentation/safari-release-notes/safari-14_1-release-notes
+    js.ArbitraryModuleNamespaceNames.Safari = { '14.1': { force: true } }
+    js.ArbitraryModuleNamespaceNames.IOS = { '14.5': { force: true } }
   }
 
   // Import assertions (note: these were removed from the JavaScript specification and never standardized)
   {
-    // From https://github.com/nodejs/node/blob/master/doc/changelogs/CHANGELOG_V16.md#16.14.0
-    js.ImportAssertions.Node = { '16.14': { force: true } }
+    js.ImportAssertions.Node = {
+      // From https://github.com/nodejs/node/blob/master/doc/changelogs/CHANGELOG_V16.md#16.14.0
+      '16.14': { force: true },
+
+      // Manually tested using a binary from https://nodejs.org/en/download/prebuilt-binaries
+      '22': { force: false },
+    }
 
     // MDN data is wrong here: https://bugs.webkit.org/show_bug.cgi?id=251600
     delete js.ImportAssertions.IOS
     delete js.ImportAssertions.Safari
   }
 
+  // Import attributes (the replacement for import assertions)
+  {
+    // Manually tested using binaries from https://nodejs.org/en/download/prebuilt-binaries
+    js.ImportAttributes.Node = {
+      '18.20': { force: true },
+      '19': { force: false },
+      '20.10': { force: true },
+    }
+  }
+
   // MDN data is wrong here: https://www.chromestatus.com/feature/6482797915013120
   js.ClassStaticBlocks.Chrome = { 91: { force: true } }
 
