@@ -673,7 +673,21 @@ func RangeOfIdentifier(source logger.Source, loc logger.Loc) logger.Range {
 	return source.RangeOfString(loc)
 }
 
-func RangeOfImportAssertOrWith(source logger.Source, assertOrWith ast.AssertOrWithEntry) logger.Range {
+type KeyOrValue uint8
+
+const (
+	KeyRange KeyOrValue = iota
+	ValueRange
+	KeyAndValueRange
+)
+
+func RangeOfImportAssertOrWith(source logger.Source, assertOrWith ast.AssertOrWithEntry, which KeyOrValue) logger.Range {
+	if which == KeyRange {
+		return RangeOfIdentifier(source, assertOrWith.KeyLoc)
+	}
+	if which == ValueRange {
+		return source.RangeOfString(assertOrWith.ValueLoc)
+	}
 	loc := RangeOfIdentifier(source, assertOrWith.KeyLoc).Loc
 	return logger.Range{Loc: loc, Len: source.RangeOfString(assertOrWith.ValueLoc).End() - loc.Start}
 }
