@@ -132,9 +132,10 @@ const (
 	ES2020
 	ES2021
 	ES2022
+	ES2023
 )
 
-type Loader uint8
+type Loader uint16
 
 const (
 	LoaderNone Loader = iota
@@ -146,9 +147,11 @@ const (
 	LoaderDefault
 	LoaderEmpty
 	LoaderFile
+	LoaderGlobalCSS
 	LoaderJS
 	LoaderJSON
 	LoaderJSX
+	LoaderLocalCSS
 	LoaderText
 	LoaderTS
 	LoaderTSX
@@ -282,9 +285,11 @@ type BuildOptions struct {
 	MangleQuoted      MangleQuoted           // Documentation: https://esbuild.github.io/api/#mangle-props
 	MangleCache       map[string]interface{} // Documentation: https://esbuild.github.io/api/#mangle-props
 	Drop              Drop                   // Documentation: https://esbuild.github.io/api/#drop
+	DropLabels        []string               // Documentation: https://esbuild.github.io/api/#drop-labels
 	MinifyWhitespace  bool                   // Documentation: https://esbuild.github.io/api/#minify
 	MinifyIdentifiers bool                   // Documentation: https://esbuild.github.io/api/#minify
 	MinifySyntax      bool                   // Documentation: https://esbuild.github.io/api/#minify
+	LineLimit         int                    // Documentation: https://esbuild.github.io/api/#line-limit
 	Charset           Charset                // Documentation: https://esbuild.github.io/api/#charset
 	TreeShaking       TreeShaking            // Documentation: https://esbuild.github.io/api/#tree-shaking
 	IgnoreAnnotations bool                   // Documentation: https://esbuild.github.io/api/#ignore-annotations
@@ -320,6 +325,7 @@ type BuildOptions struct {
 	Loader            map[string]Loader // Documentation: https://esbuild.github.io/api/#loader
 	ResolveExtensions []string          // Documentation: https://esbuild.github.io/api/#resolve-extensions
 	Tsconfig          string            // Documentation: https://esbuild.github.io/api/#tsconfig
+	TsconfigRaw       string            // Documentation: https://esbuild.github.io/api/#tsconfig-raw
 	OutExtension      map[string]string // Documentation: https://esbuild.github.io/api/#out-extension
 	PublicPath        string            // Documentation: https://esbuild.github.io/api/#public-path
 	Inject            []string          // Documentation: https://esbuild.github.io/api/#inject
@@ -364,6 +370,7 @@ type BuildResult struct {
 type OutputFile struct {
 	Path     string
 	Contents []byte
+	Hash     string
 }
 
 // Documentation: https://esbuild.github.io/api/#build
@@ -413,9 +420,11 @@ type TransformOptions struct {
 	MangleQuoted      MangleQuoted           // Documentation: https://esbuild.github.io/api/#mangle-props
 	MangleCache       map[string]interface{} // Documentation: https://esbuild.github.io/api/#mangle-props
 	Drop              Drop                   // Documentation: https://esbuild.github.io/api/#drop
+	DropLabels        []string               // Documentation: https://esbuild.github.io/api/#drop-labels
 	MinifyWhitespace  bool                   // Documentation: https://esbuild.github.io/api/#minify
 	MinifyIdentifiers bool                   // Documentation: https://esbuild.github.io/api/#minify
 	MinifySyntax      bool                   // Documentation: https://esbuild.github.io/api/#minify
+	LineLimit         int                    // Documentation: https://esbuild.github.io/api/#line-limit
 	Charset           Charset                // Documentation: https://esbuild.github.io/api/#charset
 	TreeShaking       TreeShaking            // Documentation: https://esbuild.github.io/api/#tree-shaking
 	IgnoreAnnotations bool                   // Documentation: https://esbuild.github.io/api/#ignore-annotations
@@ -466,6 +475,7 @@ type ServeOptions struct {
 	Servedir  string
 	Keyfile   string
 	Certfile  string
+	Fallback  string
 	OnRequest func(ServeOnRequestArgs)
 }
 
@@ -566,6 +576,7 @@ type ResolveOptions struct {
 	ResolveDir string
 	Kind       ResolveKind
 	PluginData interface{}
+	With       map[string]string
 }
 
 // Documentation: https://esbuild.github.io/plugins/#resolve-results
@@ -605,6 +616,7 @@ type OnResolveArgs struct {
 	ResolveDir string
 	Kind       ResolveKind
 	PluginData interface{}
+	With       map[string]string
 }
 
 // Documentation: https://esbuild.github.io/plugins/#on-resolve-results
@@ -637,6 +649,7 @@ type OnLoadArgs struct {
 	Namespace  string
 	Suffix     string
 	PluginData interface{}
+	With       map[string]string
 }
 
 // Documentation: https://esbuild.github.io/plugins/#on-load-results
@@ -665,6 +678,7 @@ const (
 	ResolveJSDynamicImport
 	ResolveJSRequireResolve
 	ResolveCSSImportRule
+	ResolveCSSComposesFrom
 	ResolveCSSURLToken
 )
 
